==> nextcloud-25.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/tr.js <==
OC.L10N.register(
    "photos",
    {
    "Photos" : "Fotoğraflar",
    "Your memories under your control" : "Anılarınızın denetimi sizde",
    "All media" : "Tüm ortamlar",
    "Videos" : "Görüntüler",
    "Albums" : "Albümler",
    "Collaborative albums" : "İşbirliği albümleri",
    "People" : "Kişiler",
    "Folders" : "Klasörler",
    "Favorites" : "Sık kullanılanlar",
    "On this day" : "Bugün",
    "Shared with you" : "Sizinle paylaşılanlar",
    "Tags" : "Etiketler",
    "Locations" : "Konumlar",
    "Photos settings" : "Fotoğraflar ayarları",
    "Mark selection as favorite" : "Seçilmişleri sık kullanılanlara ekle",
    "Add selection to favorites" : "Seçilmişleri sık kullanılanlara ekle",
    "Remove selection from favorites" : "Seçilmişleri sık kullanılanlardan çıkar",
    "Name of the album" : "Albümün adı",
    "Location of the album" : "Albümün konumu",
    "Go back to the previous view." : "Önceki görünüme geri dön.",
    "Back" : "Geri",
    "Go to the add collaborators view." : "Katılımcı ekleme görünümüne gider.",
    "Add collaborators" : "Katılımcı ekle",
    "Save." : "Kaydeder.",
    "Create the album." : "Albüm ekler.",
    "Save" : "Kaydet",
    "Create album" : "Albüm ekle",
    "Back to the new album form." : "Albüm ekleme formuna geri döner.",
    "Add to Album" : "Albüme ekle",
    "Add selection to album {ablumName}" : "Seçilmişleri {ablumName} albümüne ekle",
    "Create a new album." : "Yeni bir albüm ekler.",
    "Create new album" : "Yeni albüm ekle",
    "New album" : "Yeni albüm",
    "_%n item_::_%n photos and videos_" : ["%n öge","%n fotoğraf ve görüntü"],
    "_Share with %n user_::_Share with %n users_" : ["%n kullanıcı ile paylaş","%n kullanıcı ile paylaş"],
    "Add people or groups who can edit your album" : "Albümünüzü düzenleyebilecek kişi ya da grupları ekleyin",
    "Search for collaborators" : "Katılımcı arama",
    "Search people or groups" : "Kişi ya da grup arama",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesine ekle",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
    "Public link copied!" : "Herkese açık bağlantı kopyalandı!",
    "Copy public link" : "Herkese açık bağlantıyı kopyala",
    "Share via public link" : "Herkese açık bağlantı ile paylaş",
    "Failed to fetch collaborators list." : "Katılımcıların listesi alınamadı.",
    "This collection does not exist" : "Derleme bulunamadı",
    "An error occurred" : "Bir sorun çıktı",
    "_%n photos_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "Select image {imageName}" : "{imageName} görselini seç",
    "The file is in the favorites" : "Bu dosya sık kullanılar içinde",
    "Open the full size \"{name}\" image" : "\"{name}\" fotoğrafını tam boyutunda aç",
    "There are no photos or videos yet!" : "Henüz bir fotoğraf ya da görüntü yok!",
    "Add to {destination}" : "{destination} üzerine ekle",
    "Open the \"{name}\" sub-directory" : "\"{name}\" alt klasörünü aç",
    "Back to {folder}" : "{folder} klasörüne geri dön",
    "Share this folder" : "Bu klasörü paylaş",
    "_{years} year ago_::_{years} years ago_" : ["{years} yıl önce","{years} yıl önce"],
    "Enable squared photos view" : "Kare fotoğraf görünümü kullanılsın",
    "Default Photos upload and Albums location" : "Varsayılan Fotoğraflar yükleme ve Albümler konumu",
    "Select the default location for your media" : "Ortamlarınızın varsayılan konumunu seçin",
    "Invalid location selected" : "Seçilen konum geçersiz",
    "View" : "Görüntüle",
    "Photos directory" : "Fotoğraflar klasörü",
    "_%n photo_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "Manage collaborators for this album" : "Bu albümün katılımcılarını yönet",
    "Open actions menu" : "İşlemler menüsünü aç",
    "Edit album details" : "Albüm ayrıntılarını düzenle",
    "Download all files in album" : "Albümdeki tüm dosyaları indir",
    "Delete album" : "Albümü sil",
    "Download selected files" : "Seçilmiş dosyaları indir",
    "Remove selection from album" : "Seçilmişleri albümden kaldır",
    "This album does not have any photos or videos yet!" : "Bu albümde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to this album" : "Bu albüme fotoğraflar ekle",
    "Add photos to the album" : "Albüme fotoğraflar ekle",
    "Save collaborators for this album." : "Bu albümün katılımcılarını kaydet.",
    "Cover photo for album {albumName}" : "{albumName} albümünün kapak görseli",
    "There is no album yet!" : "Henüz bir albüm yok!",
    "This person could not be found" : "Bu kişi bulunamadı",
    "Rename person" : "Kişiyi yeniden adlandır",
    "Merge with different person" : "Başka bir kişi ile birleştir",
    "Download selected photos" : "Seçilmiş fotoğrafları indir",
    "Favorite" : "Sık kullanılanlara ekle",
    "Remove from favorites" : "Sık kullanılanlardan çıkar",
    "Remove person" : "Kişiyi sil",
    "Name of this person" : "Bu kişinin adı",
    "Merge person" : "Kişiyi birleştir",
    "_Remove photo from person_::_Remove photos from person_" : ["Fotoğrafı kişiden kaldır","Fotoğrafları kişiden kaldır"],
    "This might take some time depending on the size of your photo library." : "Bu işlemin tamamlanması fotoğraf arşivinizin boyutuna bağlı olarak biraz zaman alabilir.",
    "Recognized people will show up here" : "Tanınan kişiler burada görüntülenir",
    "This folder does not exist" : "Bu klasör bulunamadı",
    "Loading folders …" : "Klasörler yükleniyor…",
    "No photos in here" : "Burada herhangi bir fotoğraf yok",
    "Shared albums" : "Paylaşılmış albümler",
    "Cover photo for shared album {albumName}." : "{albumName} paylaşılmış albümünün kapak görseli.",
    "Back to tags overview" : "Etiket özetine geri dön",
    "No photos with this tag yet" : "Henüz bu şekilde etiketlenmiş bir fotoğraf yok",
    "No tags yet" : "Henüz bir etiket yok",
    "Photos with tags will show up here" : "Etiketlenmiş fotoğraflar burada görüntülenir",
    "Popular tags" : "Sık kullanılan etiketler",
    "Add" : "Ekle",
    "Create a new album" : "Yeni bir albüm ekle",
    "Add selection to an album" : "Seçilmişleri bir albüme ekle",
    "Add to album" : "Albüme ekle",
    "Delete selection" : "Seçilmişleri sil",
    "Failed to fetch faces list." : "Yüzlerin listesi alınamadı.",
    "Tagged photos" : "Etiketlenmiş fotoğraflar",
    "Failed to create {albumName}." : "{albumName} albümü oluşturulamadı.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} albümünün adı {newAlbumName} olarak değiştirilemedi.",
    "Failed to rename {oldName} to {faceName}." : "{oldName} adı {faceName} olarak değiştirilemedi.",
    "Failed to delete {faceName}." : "{faceName} silinemedi.",
    "Failed to delete {fileId}." : "{fileId} silinemedi.",
    "Failed to delete {fileName}." : "{fileName} silinemedi.",
    "Failed to set favorite state for {fileId}." : "{fileId} için sık kullanılan durumu ayarlanamadı.",
    "Failed to set favorite state for {fileName}." : "{fileName} için sık kullanılan durumu ayarlanamadı.",
    "Your photos" : "Fotoğraflarınız",
    "Your videos" : "Görüntüleriniz",
    "Your folders" : "Klasörleriniz",
    "Settings" : "Ayarlar"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/photos/l10n/tr.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Herkese açık bağlantı",
    "Photos" : "Fotoğraflar",
    "Your memories under your control" : "Anılarınızın denetimi sizde",
    "All media" : "Tüm ortamlar",
    "Videos" : "Görüntüler",
    "Albums" : "Albümler",
    "Collaborative albums" : "İş birlikli albümler",
    "People" : "Kişiler",
    "Folders" : "Klasörler",
    "Favorites" : "Sık kullanılanlar",
    "On this day" : "Bugün",
    "Shared with you" : "Sizinle paylaşılanlar",
    "Tags" : "Etiketler",
    "Places" : "Yerler",
    "Map" : "Harita",
    "Photos settings" : "Fotoğraflar ayarları",
    "Mark selection as favorite" : "Seçilmişleri sık kullanılanlara ekle",
    "Add selection to favorites" : "Seçilmişleri sık kullanılanlara ekle",
    "Remove selection from favorites" : "Seçilmişleri sık kullanılanlardan çıkar",
    "Name of the album" : "Albümün adı",
    "Location of the album" : "Albümün konumu",
    "Go back to the previous view." : "Önceki görünüme geri dön.",
    "Back" : "Geri",
    "Go to the add collaborators view." : "Katılımcı ekleme görünümüne gider.",
    "Add collaborators" : "Katılımcı ekle",
    "Save." : "Kaydeder.",
    "Create the album." : "Albüm ekler.",
    "Save" : "Kaydet",
    "Create album" : "Albüm ekle",
    "Back to the new album form." : "Albüm ekleme formuna geri döner.",
    "Add to Album" : "Albüme ekle",
    "Add selection to album {albumName}" : "Seçilmişleri {albumName} albümüne ekle",
    "Shared by" : "Paylaşan",
    "Create a new album." : "Yeni bir albüm ekler.",
    "Create new album" : "Yeni albüm ekle",
    "New album" : "Yeni albüm",
    "_%n item_::_%n photos and videos_" : ["%n öge","%n fotoğraf ve görüntü"],
    "Add people or groups who can edit your album" : "Albümünüzü düzenleyebilecek kişi ya da grupları ekleyin",
    "Search people or groups" : "Kişi ya da grup arama",
    "No recommendations. Start typing." : "Herhangi bir öneri yok. Yazmaya başlayın.",
    "Group" : "Grup",
    "Remove {collaboratorLabel} from the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesinden çıkar",
    "Copy the public link" : "Herkese açık bağlantıyı kopyala",
    "Public link copied!" : "Herkese açık bağlantı kopyalandı!",
    "Copy public link" : "Herkese açık bağlantıyı kopyala",
    "Delete the public link" : "Herkese açık bağlantıyı sil",
    "Create public link share" : "Herkese açık paylaşılan bağlantı oluştur",
    "Share via public link" : "Herkese açık bağlantı ile paylaş",
    "Failed to fetch collaborators list." : "Katılımcıların listesi alınamadı.",
    "Failed to update album." : "Albüm güncellenemedi",
    "This collection does not exist" : "Derleme bulunamadı",
    "An error occurred" : "Bir sorun çıktı",
    "_%n photos_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n ilişkilendirilmemiş fotoğraf","%n ilişkilendirilmemiş fotoğraf"],
    "Select image {imageName}" : "{imageName} görselini seç",
    "The file is in the favorites" : "Bu dosya sık kullanılar içinde",
    "Open the full size \"{name}\" image" : "\"{name}\" fotoğrafını tam boyutunda aç",
    "There are no photos or videos yet!" : "Henüz bir fotoğraf ya da görüntü yok!",
    "Add to {destination}" : "{destination} üzerine ekle",
    "Open the \"{name}\" sub-directory" : "\"{name}\" alt klasörünü aç",
    "Back to {folder}" : "{folder} klasörüne geri dön",
    "Share this folder" : "Bu klasörü paylaş",
    "_{years} year ago_::_{years} years ago_" : ["{years} yıl önce","{years} yıl önce"],
    "Enable squared photos view" : "Kare fotoğraf görünümü kullanılsın",
    "Default Photos upload and Albums location" : "Varsayılan Fotoğraflar yükleme ve Albümler konumu",
    "Choose default Photos upload and Albums location" : "Varsayılan Fotoğraflar yüklemesini ve Albümlerin konumu seçin",
    "Select the default location for your media" : "Ortamlarınızın varsayılan konumunu seçin",
    "Invalid location selected" : "Seçilen konum geçersiz",
    "View" : "Görüntüle",
    "Photos directory" : "Fotoğraflar klasörü",
    "_%n photo_::_%n photos_" : ["%n fotoğraf","%n fotoğraf"],
    "Unselect all" : "Tümünü bırak",
    "Manage collaborators for this album" : "Bu albümün katılımcılarını yönet",
    "Open actions menu" : "İşlemler menüsünü aç",
    "Edit album details" : "Albüm ayrıntılarını düzenle",
    "Download all files in album" : "Albümdeki tüm dosyaları indir",
    "Delete album" : "Albümü sil",
    "Download selected files" : "Seçilmiş dosyaları indir",
    "Remove selection from album" : "Seçilmişleri albümden kaldır",
    "This album does not have any photos or videos yet!" : "Bu albümde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to this album" : "Bu albüme fotoğraflar ekle",
    "Add photos to {albumName}" : "{albumName} albümüne fotoğraflar ekle",
    "Manage collaborators" : "Katılımcı yönetimi",
    "Save collaborators for this album." : "Bu albümün katılımcılarını kaydet.",
    "Cover photo for album {albumName}" : "{albumName} albümünün kapak görseli",
    "There is no album yet!" : "Henüz bir albüm yok!",
    "This person could not be found" : "Bu kişi bulunamadı",
    "Rename person" : "Kişiyi yeniden adlandır",
    "Merge with different person" : "Başka bir kişi ile birleştir",
    "Download selected photos" : "Seçilmiş fotoğrafları indir",
    "Favorite" : "Sık kullanılanlara ekle",
    "Remove from favorites" : "Sık kullanılanlardan çıkar",
    "Remove person" : "Kişiyi sil",
    "Name of this person" : "Bu kişinin adı",
    "Merge person" : "Kişiyi birleştir",
    "Move to different person" : "Farklı bir kişiye aktar",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Fotoğrafı başka bir kişiye aktar","Fotoğrafları başka bir kişiye aktar"],
    "_Remove photo from person_::_Remove photos from person_" : ["Fotoğrafı kişiden kaldır","Fotoğrafları kişiden kaldır"],
    "This might take some time depending on the size of your photo library." : "Bu işlemin tamamlanması fotoğraf arşivinizin boyutuna bağlı olarak biraz zaman alabilir.",
    "Recognized people will show up here" : "Tanınan kişiler burada görüntülenir",
    "This folder does not exist" : "Bu klasör bulunamadı",
    "Loading folders …" : "Klasörler yükleniyor…",
    "No photos in here" : "Burada herhangi bir fotoğraf yok",
    "This place does not have any photos or videos yet!" : "Bu yerde henüz bir fotoğraf ya da görüntü yok!",
    "Add photos to this place" : "Bu yere fotoğraflar ekle",
    "Cover photo for place {placeName}" : "{placeName} yerinin kapak görseli",
    "There is no place yet!" : "Henüz bir yer yok!",
    "Cover photo for shared album {albumName}." : "{albumName} paylaşılmış albümünün kapak görseli.",
    "Back to tags overview" : "Etiket özetine geri dön",
    "No photos with this tag yet" : "Henüz bu şekilde etiketlenmiş bir fotoğraf yok",
    "No tags yet" : "Henüz bir etiket yok",
    "Photos with tags will show up here" : "Etiketlenmiş fotoğraflar burada görüntülenir",
    "Popular tags" : "Sık kullanılan etiketler",
    "Add" : "Ekle",
    "Add to album" : "Albüme ekle",
    "Delete selection" : "Seçilmişleri sil",
    "No photos or videos in here" : "Henüz bir fotoğraf ya da görüntü yok",
    "Unassigned faces" : "İlişkilendirilmemiş yüzler",
    "Failed to fetch collection." : "Derleme alınamadı",
    "Failed to fetch collections list." : "Derleme listesi alınamadı.",
    "Failed to fetch faces list." : "Yüzlerin listesi alınamadı.",
    "All your media" : "Tüm ortamlarınız",
    "Album {title}" : "{title} albümü",
    "Shared Albums" : "Paylaşılmış albümler",
    "Shared album {title}" : "{title} paylaşılmış albümü",
    "Public album {title}" : "{title} herkese açık albüm",
    "Tagged photos" : "Etiketlenmiş fotoğraflar",
    "Tagged photo {title}" : "{title} etiketlenmiş fotoğraf",
    "{title}'s face" : "{title} yüzü",
    "Failed to rename {oldName} to {faceName}." : "{oldName} adı {faceName} olarak değiştirilemedi.",
    "Failed to delete {faceName}." : "{faceName} silinemedi.",
    "Failed to delete {fileId}." : "{fileId} silinemedi.",
    "Failed to delete {fileName}." : "{fileName} silinemedi.",
    "Failed to set favorite state for {fileId}." : "{fileId} için sık kullanılan durumu ayarlanamadı.",
    "Failed to set favorite state for {fileName}." : "{fileName} için sık kullanılan durumu ayarlanamadı.",
    "Locations" : "Konumlar",
    "_Share with %n user_::_Share with %n users_" : ["%n kullanıcı ile paylaş","%n kullanıcı ile paylaş"],
    "Search for collaborators" : "Katılımcı ara",
    "Add {collaboratorLabel} to the collaborators list" : "{collaboratorLabel} kullanıcısını katılımcı listesine ekle",
    "No collaborators available" : "Seçilebilecek bir katılımcı yok",
    "Failed to fetch album." : "Albüm alınamadı",
    "Add photos to the album" : "Albüme fotoğraflar ekle",
    "Failed to fetch albums list." : "Albümlerin listesi alınamadı.",
    "Shared albums" : "Paylaşılmış albümler",
    "Create a new album" : "Yeni bir albüm ekle",
    "Add selection to an album" : "Seçilmişleri bir albüme ekle",
    "Failed to create {albumName}." : "{albumName} albümü oluşturulamadı.",
    "Failed to rename {currentAlbumName} to {newAlbumName}." : "{currentAlbumName} albümünün adı {newAlbumName} olarak değiştirilemedi."
},
"nplurals=2; plural=(n > 1);");
